@@ -91,21 +91,29 @@ fn handle_search(
                 .iter()
                 .map(|p| format!("https://{}/newapi/q.php?q={}&cat=", p, query.as_str()))
                 .collect::<Vec<_>>();
-            let mut r = None;
+            let mut result = None;
             for proxy in proxies {
-                r = match search(proxy.clone(), show_proxy_list, query_unencoded, max_results)? {
-                    Some(r) => Some(r),
-                    None => {
+                result = match search(proxy.clone(), show_proxy_list, query_unencoded, max_results)
+                {
+                    Ok(Some(r)) => Some(r),
+                    Ok(None) => {
                         status_s("Nothing found...".to_string());
                         continue;
                     }
+                    Err(e) => {
+                        status_s(format!("Error {}", e));
+                        continue;
+                    }
                 };
-                if r.is_some() {
-                    break;
+                if let Some(ref r) = result {
+                    if !r.is_empty() {
+                        break;
+                    } else {
+                        result = None;
+                    }
                 }
             }
-
-            r
+            result
         } else {
             search(proxy_search, show_proxy_list, query_unencoded, max_results)?
         }
